# A few R commands to analyse a lung cancer data set from 
# the LogXact Manual. " ... a case-control study to assess
# the risk of developing lung cancer in women who had previously
# suffered from breast cancer. The covariates are radiation
# therapy for breast cancer and smoking history. The data
# consisted of 18 matched sets containing a total of 18 cases
# of lung cancer and 52 controls. The matching was based on
# age and date of diagnosis of the breast cancer."
#
# These data were analyzed by Heinze and Schemper (2002) in
# their paper on Firth logistic regression. (Accounted for
# matching by adding stratum effects to a logistic regression;
# i.e., not cond'l logistic regression.). Inference of interaction
# is not possible.

# Read in the data 
dat = read.csv("lungCa.csv")
summary(dat)

# Conditional logistic regression
library(survival) # Use the clogit() function from the survival pkg.
# main effects
fit1=clogit(case~radiation+smoke+strata(Stratum),data=dat) 
summary(fit1)
# interaction
fit2=clogit(case~radiation*smoke+strata(Stratum),data=dat) 
# Warning of possibly infinite regression coefficients
summary(fit2)


# Logistic regression analysis, ignoring the matching
# main effects
fit1=glm(case~radiation+smoke,data=dat,family=binomial())
summary(fit1)
# interaction
fit2=glm(case~radiation*smoke,data=dat,family=binomial())
summary(fit2)
