# Draw Firth-penalized profile log-likelihoods.
#------------------------------------------

FirthpenLkhd = function(dat,beta1grid=seq(from=-5,to=5,length=100)) {
  # - The data frame dat is assumed to include a binary disease status 
  # indicator, a categorical variable matchedset, and covariates. The 
  # covariate of interest is assumed to be the first covariate,
  # followed by any nuisance covariates.
  # - beta1grid is the grid of values over which to calculate the penalized
  # profile log-likelihood for drawing
  nbeta = ncol(dat) - 2
  case = dat$case
  # Make a new data frame with case, stratum indicator variables for matched sets,
  # and then the covariates.
  X = getDesignMat(dat)
  # calculate the profile likelihood for the parameter of 
  # interest, assumed to be the first log-OR, beta1.
  pp = rep(NA,length(beta1grid))
  for(i in 1:length(beta1grid)) {
    print(i)
    pp[i] = FirthProfLogLkhd(beta1grid[i],X,case)
  }
  plot(beta1grid,pp,xlab=expression(beta[1]),ylab="penalized profile lkhd",
       type="l")
  out= list(beta1grid = beta1grid, profileLkhd = pp)
  return(out)
}
#------------------------------------------------
# Worker functions called by FirthpenLkhd()
getDesignMat = function(dat) {
  # Construct the design matrix. In hindsight, could have just used
  # R's model.matrix() function to build design matrix, but 
  # for some reason (forgot why) insisted on one dummy variable for
  # each matched set.
  nmatch = nrow(dat)/5 # assume matched sets are 1 case, 4 controls
  fm = as.factor(dat$matchedset)
  # dummy variables as indicators of matched set ID:
  inds = sapply(1:nmatch,FUN=function(i) { as.numeric(fm==i)})
  colnames(inds) = paste0("m",1:ncol(inds))
  covs = as.matrix(dat[,3:ncol(dat)])
  return(cbind(inds,covs))
}
FirthProfLogLkhd = function(beta,X,case) {
  # First find the profile log likelihood for the log odds ratio parameters
  # (betas) by profiling out stratum effects (alpha's)
  alphaInds = (1:(ncol(X)-length(beta))) # stratum effects come first in X
  betaInds = setdiff(1:ncol(X),alphaInds)
  fp = function(pars,X,case) {
    return(logLkhd(pars,X,case) + 0.5*log(det(FInfo(pars,X))))
  }
  # call a generic profiler() function that maximizes a function, func,
  # over variables in argument maxInd, holding fixed the variables in 
  # argument fixedInd at values parsFixed. The rest of the arguments 
  # are arguments to func.
  oo = profiler(func=fp,maxInd=alphaInds,fixedInd=betaInds,parsFixed=beta,
                X=X,case=case)
  # oo$par is our argmax, and oo$value is the profile log-likelihood
  # value at argmax
  return(oo$value)
}

# profiler(), logLkhd(), FInfo() and expit() are in source file HOApenLkhd.R
# source("Functions/HOApenLkhd.R")