# A few R commands to read in the DES data and try Fisher's exact
# test of the DES effect and logistic regression to adjust for
# maternal smoking as a possible confounder.

# Read in DES data 
DES = read.csv("Data/DES.csv")
summary(DES)

mytable<-function(case,exposure){
  tab = table(exposure,case)[2:1,2:1]
  rownames(tab)<-c("exposed","unexposed")
  colnames(tab)<-c("case","control")
  print(tab)
  print(fisher.test(tab)$estimate)
  print(fisher.test(tab)$p.value)
}

# ORs and Fisher's Exact for each exposure, starting with DES
mytable(DES$case,DES$DES)
mytable(DES$case,DES$matern.smoke)
mytable(DES$case,DES$bleeding)
mytable(DES$case,DES$prior.loss)
mytable(DES$case,DES$breast.feed)
mytable(DES$case,DES$IU.X.ray)

# Conditional logistic regression
library(survival) # Use the clogit() function from the survival pkg.
fit1=clogit(case~DES+strata(matched.set),data=DES,iter.max=30) 
# likelihood has converged after 21 iterations, but software
# warns that DES coeficient has not 
summary(fit1)
# Aee maternal smoking
fit2=clogit(case~DES+matern.smoke+strata(matched.set),data=DES,iter.max=30) 
summary(fit2)

# Logistic regression analysis, ignoring the matching
fit1=glm(case~DES,data=DES,family=binomial())
summary(fit1) # No warnings, but huge estimated DES effect
# Add maternal smoking
fit2=glm(case~DES+matern.smoke,data=DES,family=binomial())
summary(fit2) # Warnings of fitted probs near 0/1. Estimates unstable.